//BOI 2012 - Mobile Checker
//Takes 2 arguments: output file name and correct answer file name (provided in tests).
//Returns 0 if output is OK and 1 otherwise. Might print a detailed message if an output is not correct.

#include <iostream>
#include <fstream>
#include <cmath>
#include <cstdio>
#include <cmath>
#include <cstring>
#include <limits>

using namespace std;

FILE *ansf = NULL;
FILE *out= NULL;

#define maxl 1024

void cleanup()
{
	if(ansf)fclose(ansf);
	ansf = NULL;
	if(out)fclose(out);
	out = NULL;
}

int main(int argc, char* arg[])
{
	if(argc < 3){
		cout << "Wrong use of checker" <<endl;
		return 2;
	}
	
	FILE *out = fopen(arg[1], "r");
	if(!out){
		cout << "Can't open output file" <<endl;
		return 1;
	}
	
	FILE *ansf = fopen(arg[2], "r");
	if(!ansf)
	{
		cout << "Can't open answer file" <<endl;
		cleanup();
		return 2;
	}

	double ans;
	char txt[2*maxl];
	if( !fscanf(ansf, "%lf", &ans)  )
	{
		cout << "Empty answer file";
		cleanup();
		return 2;
	}
	if( fgets(txt, 2*maxl, out) == NULL)
	{
		cout << "Empty output";
		cleanup();
		return 1;
	}
	int l = strlen(txt);
	if(l>= maxl){
		cout << "Output too long" << endl;
		cleanup();
		return 1;
	}

	for(int i=0; i<l; i++)
	{
		if(txt[i] < 32) txt[i] = ' ';	
		if(txt[i] == 'E')txt[i] = 'e';
		else if(!((txt[i] >= '0' && txt[i] <= '9') || txt[i] == '.' || txt[i] == 'e' || txt[i] == '+' || txt[i] == '-' || txt[i] == ' ')){
			cout<< "NaN" <<endl;
			cleanup();
			return 1;
		}
	}

	int st,end;
	while(txt[st] == ' ')st++;
	
	end = l;
	while(end>0 && txt[end-1]==' ')end--;
	
	if(st >= end)
	{
		cout << "Empty output" << endl;
		cleanup();
		return 1;
	}

	fclose(out);
	out = fopen(arg[1], "r");

	double ans2 = -2012.5432012;
	if( fscanf(out,"%lf", &ans2) < 1){
		cout << "No numbers";
		cleanup();
		return 1;
	}
	
	if(fgets(txt, maxl, out) != NULL){
		l = strlen(txt);	
		for(int i=0; i<l; i++)
		{
			if(txt[i] > ' ')
			{
				cout << "Invalid output";
				cleanup();
				return 1;
			}
		}
	}

	if(ans2 != ans2 || 
		ans2 == numeric_limits<double>::infinity() ||
		ans2 == -numeric_limits<double>::infinity() )
		{
		cout << "NaN or infinity";
		cleanup();
		return 1; 
	}	

	double dif = abs(ans-ans2);
	if(dif != dif || 
		dif == numeric_limits<double>::infinity() ||
		dif == -numeric_limits<double>::infinity() )
		{
		cout << "WA";
		cleanup();
		return 1; 
	}
	
	if( dif <= 0.001001 )
	{
		cleanup();
		return 0;
	}
	
	cleanup();
	cout << "WA";
	return 1;
}
